%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%define expat_version           2.0.1

%define lib_major 3
%define lib_api 1
%define lib_name %mklibname dbus %{lib_api} %{lib_major}
%define develname %mklibname -d dbus

%define enable_test 0
%define enable_verbose 0

%define git_url git://git.freedesktop.org/git/dbus/dbus

Summary: D-Bus message bus
Name: dbus
Version: 1.10.16
Release: %mkrel 1
URL: http://www.freedesktop.org/Software/dbus
Source0: http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.gz

License: GPLv2+ or AFL
Group: System/Servers
BuildRequires: libx11-devel
BuildRequires: expat-devel >= %{expat_version}
%if !%bootstrap
BuildRequires: xmlto 
BuildRequires: docbook-dtd412-xml
BuildRequires: doxygen
%endif
BuildRequires: libtool
BuildRequires: libcap-ng-devel
BuildRequires: pkgconfig(gio-2.0) >= 2.24
BuildRequires: pkgconfig(glib-2.0) >= 2.24
BuildRequires: pkgconfig(systemd)
Requires(pre): shadow-utils
Requires(preun): rpm-helper >= 0.24.8-1
Provides: should-restart = system

%description
D-Bus is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package -n %{lib_name}
Summary: Shared library for using D-Bus
Group: System/Libraries
Requires: dbus >= %{version}
Obsoletes: %{_lib}dbus-1_3 < 1.6.0

%description -n %{lib_name}
D-Bus shared library.

%package -n %develname
Summary: Libraries and headers for D-Bus
Group: Development/C
Requires: %{name} = %{version}
Requires: %{lib_name} = %{version}
Provides: lib%{name}-1-devel = %{version}-%{release}
Provides: lib%{name}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Conflicts: %{_lib}dbus-1_0-devel
Obsoletes: %{mklibname -d dbus- 1 3} < 1.6.0
Obsoletes: %{_lib}dbus-1-devel < 1.6.0

%description -n %develname
Headers and static libraries for D-Bus.

%package x11
Summary: X11-requiring add-ons for D-Bus
Group: System/Servers
Requires: dbus = %{version}

%package doc
Summary: Developer documentation for D-BUS
Group: Documentation
Requires: dbus = %{version}
Recommends: devhelp
BuildArch: noarch
Conflicts: libdbus-1-devel < 1.2.20
Conflicts: lib64dbus-1-devel < 1.2.20

%description doc 
This package contains developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file.

%description x11
D-Bus contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%prep
%setup -q
%autopatch -p1

%build

COMMON_ARGS="--disable-static --disable-selinux --with-system-socket=/run/dbus/system_bus_socket --libexecdir=%{_libexecdir}/dbus-%{lib_api}" 

#### Build once with tests to make check
%if %{enable_test}
%configure2_5x $COMMON_ARGS --enable-tests=yes --enable-systemd \
               --enable-verbose-mode=yes \
               --enable-asserts=yes \
               --disable-doxygen-docs \
               --enable-userdb-cache \
               --disable-xml-docs
DBUS_VERBOSE=1 %make
make check

#### Clean up and build again 
make clean
%endif 

%configure2_5x $COMMON_ARGS --disable-tests --disable-asserts \
%if !%bootstrap
 --enable-doxygen-docs --enable-xml-docs \
 --htmldir=%{_datadir}/devhelp/books/%{name} \
%endif
%if %enable_verbose
 --enable-verbose-mode=yes
%else 
 --enable-verbose-mode=no
%endif
%make

%check
make check

%install
%makeinstall_std

mkdir -p %{buildroot}%{_sysconfdir}/X11/xinit.d
cat << EOF > %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus
# to be sourced
if [ -z "\$DBUS_SESSION_BUS_ADDRESS" ]; then
  eval \`/usr/bin/dbus-launch --exit-with-session --sh-syntax\`
fi
EOF
chmod 755 %{buildroot}%{_sysconfdir}/X11/xinit.d/30dbus

# create directory
mkdir %{buildroot}%{_datadir}/dbus-%{lib_api}/interfaces

# This is legacy
rm -rf %{buildroot}%{_unitdir}/dbus.target.wants

# link devhelp docs in docdir
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
pushd %{buildroot}%{_datadir}/devhelp/books/%{name}
for f in *; do
  ln -s ../../devhelp/books/%{name}/$f %{buildroot}%{_docdir}/%{name}-doc
done
popd

#remove unpackaged file
find %{buildroot} -name '*.la' -delete

%pre
# (cg) Do not require/use rpm-helper helper macros... we must do this manually
# to avoid dep loops during install
/usr/sbin/groupadd -r messagebus 2>/dev/null || :
/usr/sbin/useradd -r -c "system user for %{name}" -g messagebus -s /sbin/nologin -d / messagebus 2>/dev/null || :

%postun
%_postun_userdel messagebus
%_postun_groupdel messagebus

%files
%doc COPYING NEWS doc/system-activation.txt
%dir %{_datadir}/doc/dbus/examples
%{_datadir}/doc/dbus/examples/GetAllMatchRules.py
%{_datadir}/doc/dbus/examples/example-session-disable-stats.conf
%{_datadir}/doc/dbus/examples/example-system-enable-stats.conf
%dir %{_sysconfdir}/dbus-%{lib_api}
%exclude %{_sysconfdir}/rc.d/init.d/*
%config(noreplace) %{_sysconfdir}/dbus-%{lib_api}/*.conf
%dir %{_localstatedir}/lib/dbus
%dir %{_libdir}/dbus-1.0
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-daemon
%{_bindir}/dbus-run-session
%{_bindir}/dbus-send
%{_bindir}/dbus-test-tool
%{_bindir}/dbus-update-activation-environment
%{_bindir}/dbus-uuidgen
%{_mandir}/man*/*
%dir %{_datadir}/dbus-%{lib_api}
%dir %{_datadir}/dbus-%{lib_api}/system.d
%dir %{_datadir}/dbus-%{lib_api}/session.d
%{_datadir}/dbus-%{lib_api}/interfaces
%{_datadir}/dbus-%{lib_api}/services
%{_datadir}/dbus-%{lib_api}/session.conf
%{_datadir}/dbus-%{lib_api}/system.conf
%{_datadir}/dbus-%{lib_api}/system-services
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%dir %{_libexecdir}/dbus-%{lib_api}
%attr(4750,root,messagebus) %{_libexecdir}/dbus-%{lib_api}/dbus-daemon-launch-helper
%{_unitdir}/dbus.service
%{_unitdir}/dbus.socket
%{_unitdir}/multi-user.target.wants/dbus.service
%{_unitdir}/sockets.target.wants/dbus.socket

%files -n %{lib_name}
%{_libdir}/*dbus-%{lib_api}*.so.%{lib_major}{,.*}

%files -n %develname
%doc ChangeLog 
%{_libdir}/libdbus-%{lib_api}.so
%{_libdir}/dbus-1.0/include
%{_libdir}/pkgconfig/dbus-%{lib_api}.pc
%{_includedir}/dbus-1.0

%files x11
%{_sysconfdir}/X11/xinit.d/*
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor

%files doc
%doc %{_datadir}/devhelp/books/dbus
%{_docdir}/%{name}-doc


%changelog
* Fri Feb 17 2017 luigiwalser <luigiwalser> 1.10.16-1.mga6
+ Revision: 1086559
- 1.10.16

* Thu Dec 15 2016 luigiwalser <luigiwalser> 1.10.14-1.mga6
+ Revision: 1075396
- 1.10.14

* Tue Jun 07 2016 tv <tv> 1.10.8-2.mga6
+ Revision: 1020635
- adjust BRs for latest systemd

* Mon May 09 2016 luigiwalser <luigiwalser> 1.10.8-1.mga6
+ Revision: 1011343
- 1.10.8

* Mon Jan 18 2016 tmb <tmb> 1.10.6-1.mga6
+ Revision: 925194
- update to 1.10.6

* Fri Oct 09 2015 tmb <tmb> 1.8.20-1.mga6
+ Revision: 888554
- update to 1.8.20

* Fri Aug 21 2015 tmb <tmb> 1.8.16-2.mga6
+ Revision: 867444
- rebuild for new gcc

* Tue Feb 10 2015 tmb <tmb> 1.8.16-1.mga5
+ Revision: 814585
- prevent forged ActivationFailure from non-root processes (CVE-2015-0245)

* Wed Jan 07 2015 colin <colin> 1.8.14-2.mga5
+ Revision: 808952
- Backport ALLOW_INTERACTIVE_AUTHORIZATION support

* Mon Jan 05 2015 tmb <tmb> 1.8.14-1.mga5
+ Revision: 808648
- 1.8.14 (security hardening)

* Sun Dec 21 2014 tmb <tmb> 1.8.12-1.mga5
+ Revision: 804688
- 1.8.12 (upstream fixes for mga#14249)

* Mon Nov 10 2014 tmb <tmb> 1.8.10-1.mga5
+ Revision: 796208
- set default auth_timeout to 30s as some systems still fail with 20s
- fix CVE-2014-7824 (mga#14494)

* Sat Oct 25 2014 tmb <tmb> 1.8.8-4.mga5
+ Revision: 793122
- update default auth_timeout to 20s

* Wed Oct 22 2014 tmb <tmb> 1.8.8-3.mga5
+ Revision: 792440
- bump default auth_timeout to 15s (mga#14251)

* Wed Oct 15 2014 umeabot <umeabot> 1.8.8-2.mga5
+ Revision: 741064
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 tmb <tmb> 1.8.8-1.mga5
+ Revision: 733997
- update to 1.8.8
- drop merged patches

* Thu Sep 25 2014 tmb <tmb> 1.6.24-1.mga5
+ Revision: 724738
- update to 1.6.24 (CVE fixes)

* Thu Sep 18 2014 umeabot <umeabot> 1.6.22-4.mga5
+ Revision: 693730
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.6.22-3.mga5
+ Revision: 678683
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Thu Sep 04 2014 tv <tv> 1.6.22-2.mga5
+ Revision: 671813
- rebuild for new systemd libraries

* Wed Jul 09 2014 luigiwalser <luigiwalser> 1.6.22-1.mga5
+ Revision: 650843
- 1.6.22 (fixes CVE-2014-3532 and CVE-2014-3533)

* Tue Jun 10 2014 tmb <tmb> 1.6.20-1.mga5
+ Revision: 635527
- 1.6.20: CVE-2014-3477: deliver activation errors correctly, fixing DoS

* Tue Jan 14 2014 tmb <tmb> 1.6.18-1.mga4
+ Revision: 566552
- make_and_run_test_nodes: avoid undefined behaviour
- fixed memory freeing if error during listing services
- update to 1.6.18 (maintenance release)

* Fri Dec 20 2013 colin <colin> 1.6.12-4.mga4
+ Revision: 559096
- Add some upstream patches to prevent double logging of dbus log messages

* Thu Oct 31 2013 colin <colin> 1.6.12-3.mga4
+ Revision: 548133
- Drop pre-script requires on rpm-helper to break dep loops
- Drop adding messagebus user to daemon group - it doesn't work/isn't needed

* Sat Oct 19 2013 umeabot <umeabot> 1.6.12-2.mga4
+ Revision: 527909
- Mageia 4 Mass Rebuild

* Thu Jun 13 2013 colin <colin> 1.6.12-1.mga4
+ Revision: 442892
- New version: 1.6.12

* Sun Jun 09 2013 fwang <fwang> 1.6.10-1.mga4
+ Revision: 441024
- new version 1.6.10

* Mon Mar 11 2013 colin <colin> 1.6.8-4.mga3
+ Revision: 402096
- Require rpm-helper for pre-install scripts (mga#9326)
- Drop useless Requires(post) as there are not post scripts

* Fri Jan 11 2013 umeabot <umeabot> 1.6.8-3.mga3
+ Revision: 348634
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 1.6.8-2.mga3
+ Revision: 321915
- Drop the 'messagebus' alias for dbus.service
- Drop no longer needed/useful preun script
- Drop no longer needed/useful post script
- Drop very old upgrade triggers
- Remove reference to legacy dbus.target
- Tidy up unneeded arguments
- Don't package /var/run/dbus dir (created by systemd when starting dbus.socket)

* Tue Oct 16 2012 colin <colin> 1.6.8-1.mga3
+ Revision: 307295
- New version: 1.6.8
- Add patch to re-ignore SIGPIPE when launching services (might help gnome-shell unlock mga#7687)

* Sun Oct 14 2012 ennael <ennael> 1.6.4-2.mga3
+ Revision: 305352
- Documentation group

* Wed Sep 12 2012 fwang <fwang> 1.6.4-1.mga3
+ Revision: 292495
- new verison 1.6.4
- we do not rely libs to be put in /lib now
- new version 1.6.4

* Thu Aug 09 2012 tv <tv> 1.6.0-2.mga3
+ Revision: 280297
- fix file list
- drop sysv service

* Fri Jun 15 2012 fwang <fwang> 1.6.0-1.mga3
+ Revision: 260701
- update file list
- New version 1.6.0

* Mon Apr 30 2012 blino <blino> 1.4.16-5.mga2
+ Revision: 234333
- do not install html doc in main package, it wastes space on live CDs
- use upstream way of installing docs and drop doxygen_to_devhelp.xsl
  (available since D-Bus 1.4.14, 2011-07-29)

* Sat Apr 28 2012 tmb <tmb> 1.4.16-4.mga2
+ Revision: 233662
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 28 2012 tmb <tmb> 1.4.16-3.mga2
+ Revision: 233558
- rebuild for versioned rpm-helper requires

* Fri Apr 06 2012 colin <colin> 1.4.16-2.mga2
+ Revision: 229297
- Drop dbus.target. No longer used in systemd

* Sat Sep 24 2011 fwang <fwang> 1.4.16-1.mga2
+ Revision: 147228
- new verrsion 1.4.16

* Wed Sep 14 2011 tmb <tmb> 1.4.14-3.mga2
+ Revision: 143580
- restore 'fix initscript to not print message when systemd is absent'
  that got dropped in last version upgrade

* Fri Sep 09 2011 tv <tv> 1.4.14-2.mga2
+ Revision: 141725
- really protect '$'

* Thu Sep 08 2011 tv <tv> 1.4.14-1.mga2
+ Revision: 141550
- new release
- enable-userdb-cache
- BuildRequires: glib2-devel
- patch 7: synchronize dbus.service and dbus.target (andrey borzenkov)
- protect '$' in xinit.d here-script
- use %%buildroot macro

* Sat Jul 16 2011 cjw <cjw> 1.4.12-1.mga2
+ Revision: 124706
- 1.4.12
- drop patch6: fixed upstream
- enable systemd support

  + rtp <rtp>
    - alloc to build dbus without xml and doxygen docs.

* Fri Feb 11 2011 misc <misc> 1.4.1-3.mga1
+ Revision: 50073
- fix initscript to not print message when systemd is absent

* Tue Jan 25 2011 dmorgan <dmorgan> 1.4.1-2.mga1
+ Revision: 39177
- Fix file list
- Fix typo
- Bump release
- Merge mdv commits 631203 631334 and 631460

* Wed Jan 12 2011 dmorgan <dmorgan> 1.4.1-1.mga1
+ Revision: 7690
- Remove mdv macros

  + blino <blino>
    - imported package dbus

